@@ -1,25 +1,20 @@
-import math
-import logging
-from dateutil.parser import parse
 import re
-import uuid
 
 
 ###
 ### DictShield documents
 ###
 
-from dictshield.base import BaseField, DictPunch
 from dictshield.document import Document
 from dictshield.fields import (StringField,
                                BooleanField,
                                URLField,
                                EmailField,
-                               LongField,
-                               ObjectIdField)
+                               LongField)
+from dictshield.fields.mongo import ObjectIdField
 
 import auth
-from timekeeping import curtime, MillisecondField
+from timekeeping import curtime
 from datamosh import OwnedModelMixin, StreamedModelMixin
 
 
@@ -103,11 +98,11 @@ class UserProfile(Document, OwnedModelMixin, StreamedModelMixin):
     """The basic things a user profile tends to carry. Isolated in separate
     class to keep separate from private data.
     """
-    ## ownable # Provided by OwnedModelMixin now. includes a name changes
-    #owner = ObjectIdField(required=True) # owner_id
-    #username = StringField(max_length=30, required=True) # owner_username
+    # Provided by OwnedModelMixin
+    #owner_id = ObjectIdField(required=True)
+    #owner_username = StringField(max_length=30, required=True)
 
-    ## streamable # provided by StreamedModelMixin now
+    # streamable # provided by StreamedModelMixin now
     #created_at = MillisecondField()
     #updated_at = MillisecondField()
 
@@ -120,7 +115,7 @@ class UserProfile(Document, OwnedModelMixin, StreamedModelMixin):
     avatar_url = URLField(max_length=255)
 
     _private_fields = [
-        'owner',
+        'owner_id',
     ]
 
     def __init__(self, *args, **kwargs):
