@@ -25,7 +25,7 @@ try:
     CORO_LIBRARY = 'gevent'
 
 ### Fallback to eventlet
-except:
+except ImportError:
     try:
         import eventlet
         eventlet.patcher.monkey_patch(all=True)
@@ -37,15 +37,12 @@ except:
 
         CORO_LIBRARY = 'eventlet'
 
-    except: ### eventlet or gevent is required.
+    except ImportError: ### eventlet or gevent is required.
         raise EnvironmentError('Y U NO INSTALL CONCURRENCY?!')
 
 
 from . import version
 
-from uuid import uuid4
-import os
-import sys
 import re
 import time
 import logging
@@ -54,15 +51,14 @@ import Cookie
 import base64
 import hmac
 import cPickle as pickle
-from functools import partial
 
-from mongrel2 import Mongrel2Connection
+from mongrel2 import Mongrel2Connection, to_bytes, to_unicode
 import ujson as json
 
-
 ###
 ### Common helpers
 ###
+HTTP_METHODS = ['get', 'post', 'put', 'delete', 'head', 'options', 'trace', 'connect']
 
 HTTP_FORMAT = "HTTP/1.1 %(code)s %(status)s\r\n%(headers)s\r\n\r\n%(body)s"
 def http_response(body, code, status, headers):
@@ -71,21 +67,13 @@ def http_response(body, code, status, headers):
     payload = {'code': code, 'status': status, 'body': body}
     content_length = 0
     if body is not None:
-        content_length = len(body)
+        content_length = len(to_bytes(body))
     headers['Content-Length'] = content_length
     payload['headers'] = "\r\n".join('%s: %s' % (k,v) for k,v in
                                      headers.items())
 
     return HTTP_FORMAT % payload
 
-### Knowledge of `to_bytes` and `to_unicode` should be together
-from mongrel2 import to_bytes
-
-def to_unicode(s, enc='utf8'):
-    """Convert anything to unicode
-    """
-    return s if isinstance(s, unicode) else unicode(str(s), encoding=enc)
-
 def _lscmp(a, b):
     """Compares two strings in a cryptographically safe way
     """
@@ -160,7 +148,7 @@ class MessageHandler(object):
     unique to the message our handler is designed for. Mix in logic as you
     realize you need it. Or rip it out. Keep your handlers lean.
 
-    Two callbacks are offered for state preperation.
+    Two callbacks are offered for state preparation.
 
     The `initialize` function allows users to add steps to object
     initialization. A mixin, however, should never use this. You could hook
@@ -172,7 +160,6 @@ class MessageHandler(object):
     that database connection we created in `initialize` to check the username
     and password from a user.
     """
-    SUPPORTED_METHODS = ()
     _STATUS_CODE = 'status_code'
     _STATUS_MSG = 'status_msg'
     _TIMESTAMP = 'timestamp'
@@ -301,19 +288,18 @@ class MessageHandler(object):
         unsupported function.
 
         In the event that an error has already occurred, _finished will be
-        set to true before this funciton call indicating we should render
+        set to true before this function call indicating we should render
         the handler and nothing else.
 
         In all cases, generating a response for mongrel2 is attempted.
         """
         self.prepare()
         if not self._finished:
-            mef = self.message.method # M-E-T-H-O-D man!
+            mef = self.message.method.lower() # M-E-T-H-O-D man!
 
             # Find function mapped to method on self
-            if mef in self.SUPPORTED_METHODS:
-                mef = mef.lower()
-                fun = getattr(self, mef)
+            if mef in HTTP_METHODS:
+                fun = getattr(self, mef, self.unsupported)
             else:
                 fun = self.unsupported
 
@@ -340,7 +326,6 @@ class WebMessageHandler(MessageHandler):
 
     Tornado's design inspired this design.
     """
-    SUPPORTED_METHODS = ("GET", "HEAD", "POST", "DELETE", "PUT", "OPTIONS")
     _DEFAULT_STATUS = 500 # default to server error
     _SUCCESS_CODE = 200
     _AUTH_FAILURE = 401
@@ -382,26 +367,15 @@ class WebMessageHandler(MessageHandler):
     ###
     ### Supported HTTP request methods are mapped to these functions
     ###
-
-    def head(self, *args, **kwargs):
-        return self.unsupported()
-
-    def get(self, *args, **kwargs):
-        return self.unsupported()
-
-    def post(self, *args, **kwargs):
-        return self.unsupported()
-
-    def delete(self, *args, **kwargs):
-        return self.unsupported()
-
-    def put(self, *args, **kwargs):
-        return self.unsupported()
-
     def options(self, *args, **kwargs):
-        """Should probably implement this in this class. Got any ideas?
+        """Default to allowing all of the methods you have defined and public
         """
-        return self.unsupported()
+        supported_methods = []
+        for mef in HTTP_METHODS:
+            if callable(getattr(self, mef, False)):
+                supported_methods.append(mef)
+        self.headers["Access-Control-Allow-Methods"] = ", ".join(mef.upper() for mef in supported_methods)
+        return self.render()
 
     def unsupported(self, *args, **kwargs):
         return self.render_error(self._NOT_FOUND)
@@ -499,7 +473,7 @@ class WebMessageHandler(MessageHandler):
         self.set_cookie(key, '', **kwargs)
 
     def delete_cookies(self):
-        """Deleats every cookie received from the user.
+        """Deletes every cookie received from the user.
         """
         for key in self.message.cookies.iterkeys():
             self.delete_cookie(key)
@@ -508,6 +482,14 @@ class WebMessageHandler(MessageHandler):
     ### Output generation
     ###
 
+    def convert_cookies(self):
+        """ Resolves cookies into multiline values.
+        """
+        cookie_vals = [c.OutputString() for c in self.cookies.values()]
+        if len(cookie_vals) > 0:
+            cookie_str = '\nSet-Cookie: '.join(cookie_vals)
+            self.headers['Set-Cookie'] = cookie_str
+
     def render(self, status_code=None, http_200=False, **kwargs):
         """Renders payload and prepares the payload for a successful HTTP
         response.
@@ -524,11 +506,7 @@ class WebMessageHandler(MessageHandler):
         if http_200:
             status_code = 200
 
-        # Resolve cookies into multiline value
-        cookie_vals = [c.OutputString() for c in self.cookies.values()]
-        if len(cookie_vals) > 0:
-            cookie_str = '\nSet-Cookie: '.join(cookie_vals)
-            self.headers['Set-Cookie'] = cookie_str
+        self.convert_cookies()
 
         response = http_response(self.body, status_code,
                                  self.status_msg, self.headers)
@@ -548,6 +526,10 @@ class JSONMessageHandler(WebMessageHandler):
         if status_code:
             self.set_status(status_code)
 
+        self.convert_cookies()
+        
+        self.headers['Content-Type'] = 'application/json'
+
         body = json.dumps(self._payload)
 
         response = http_response(body, self.status_code,
@@ -586,6 +568,9 @@ class Brubeck(object):
         # (while i figure out how to do a good abstraction via zmq)
         logging.basicConfig(level=log_level)
 
+        # Log whether we're using eventlet or gevent.
+        logging.info('Using coroutine library: %s' % CORO_LIBRARY)
+
         # A Mongrel2Connection is currently just a way to manage
         # the sockets we need to open with a Mongrel2 instance and
         # identify this particular Brubeck instance as the sender
@@ -593,7 +578,7 @@ class Brubeck(object):
             (pull_addr, pub_addr) = mongrel2_pair
             self.m2conn = Mongrel2Connection(pull_addr, pub_addr)
         else:
-            raise ValueException('No mongrel2 connection possible.')
+            raise ValueError('No mongrel2 connection possible.')
 
         # Class based route lists should be handled this way.
         # It is also possible to use `add_route`, a decorator provided by a
@@ -608,7 +593,7 @@ class Brubeck(object):
         elif callable(pool):
             self.pool = pool()
         else:
-            raise ValueException('Unable to initialize coroutine pool')
+            raise ValueError('Unable to initialize coroutine pool')
 
         # Set a base_handler for handling errors (eg. 404 handler)
         self.base_handler = base_handler
@@ -631,10 +616,10 @@ class Brubeck(object):
             if loaded_env:
                 self.template_env = loaded_env
             else:
-                raise ValueException('template_env failed to load.')
+                raise ValueError('template_env failed to load.')
 
     ###
-    ### Message routing funcitons
+    ### Message routing functions
     ###
     
     def init_routes(self, handler_tuples):
